CoinReadApiClient

Trait CoinReadApiClient 

pub trait CoinReadApiClient: ClientT {
    // Provided methods
    fn get_coins<'life0, 'async_trait>(
        &'life0 self,
        owner: Address,
        coin_type: Option<String>,
        cursor: Option<ObjectId>,
        limit: Option<usize>,
    ) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn get_all_coins<'life0, 'async_trait>(
        &'life0 self,
        owner: Address,
        cursor: Option<ObjectId>,
        limit: Option<usize>,
    ) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn get_balance<'life0, 'async_trait>(
        &'life0 self,
        owner: Address,
        coin_type: Option<String>,
    ) -> Pin<Box<dyn Future<Output = Result<Balance, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn get_all_balances<'life0, 'async_trait>(
        &'life0 self,
        owner: Address,
    ) -> Pin<Box<dyn Future<Output = Result<Vec<Balance>, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn get_coin_metadata<'life0, 'async_trait>(
        &'life0 self,
        coin_type: String,
    ) -> Pin<Box<dyn Future<Output = Result<Option<IotaCoinMetadata>, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn get_total_supply<'life0, 'async_trait>(
        &'life0 self,
        coin_type: String,
    ) -> Pin<Box<dyn Future<Output = Result<IotaSupply, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn get_circulating_supply<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<IotaCirculatingSupply, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
}
Client implementation for the CoinReadApi RPC API.

Provided Methods

fn get_coins<'life0, 'async_trait>( &'life0 self, owner: Address, coin_type: Option<String>, cursor: Option<ObjectId>, limit: Option<usize>, ) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Return all Coin<coin_type> objects owned by an address.

fn get_all_coins<'life0, 'async_trait>( &'life0 self, owner: Address, cursor: Option<ObjectId>, limit: Option<usize>, ) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Return all Coin objects owned by an address.

fn get_balance<'life0, 'async_trait>( &'life0 self, owner: Address, coin_type: Option<String>, ) -> Pin<Box<dyn Future<Output = Result<Balance, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Return the total coin balance for one coin type, owned by the address owner.

fn get_all_balances<'life0, 'async_trait>( &'life0 self, owner: Address, ) -> Pin<Box<dyn Future<Output = Result<Vec<Balance>, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Return the total coin balance for all coin type, owned by the address owner.

fn get_coin_metadata<'life0, 'async_trait>( &'life0 self, coin_type: String, ) -> Pin<Box<dyn Future<Output = Result<Option<IotaCoinMetadata>, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Return metadata (e.g., symbol, decimals) for a coin.

fn get_total_supply<'life0, 'async_trait>( &'life0 self, coin_type: String, ) -> Pin<Box<dyn Future<Output = Result<IotaSupply, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Return total supply for a coin.

fn get_circulating_supply<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<IotaCirculatingSupply, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Return the circulating supply summary.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<TypeJsonRpseeInteral> CoinReadApiClient for TypeJsonRpseeInteral
where TypeJsonRpseeInteral: ClientT,