pub trait MoveUtilsServer:
Sized
+ Send
+ Sync
+ 'static {
// Required methods
fn get_move_function_arg_types<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module: String,
function: String,
) -> Pin<Box<dyn Future<Output = RpcResult<Vec<MoveFunctionArgType>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_normalized_move_modules_by_package<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
) -> Pin<Box<dyn Future<Output = RpcResult<BTreeMap<String, IotaMoveNormalizedModule>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_normalized_move_module<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module_name: String,
) -> Pin<Box<dyn Future<Output = RpcResult<IotaMoveNormalizedModule>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_normalized_move_struct<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module_name: String,
struct_name: String,
) -> Pin<Box<dyn Future<Output = RpcResult<IotaMoveNormalizedStruct>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_normalized_move_function<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module_name: String,
function_name: String,
) -> Pin<Box<dyn Future<Output = RpcResult<IotaMoveNormalizedFunction>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
// Provided method
fn into_rpc(self) -> RpcModule<Self> { ... }
}Expand description
Server trait implementation for the MoveUtils RPC API.
Required Methods
Sourcefn get_move_function_arg_types<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module: String,
function: String,
) -> Pin<Box<dyn Future<Output = RpcResult<Vec<MoveFunctionArgType>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_move_function_arg_types<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module: String,
function: String,
) -> Pin<Box<dyn Future<Output = RpcResult<Vec<MoveFunctionArgType>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Return the argument types of a Move function, based on normalized Type.
Sourcefn get_normalized_move_modules_by_package<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
) -> Pin<Box<dyn Future<Output = RpcResult<BTreeMap<String, IotaMoveNormalizedModule>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_normalized_move_modules_by_package<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
) -> Pin<Box<dyn Future<Output = RpcResult<BTreeMap<String, IotaMoveNormalizedModule>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Return structured representations of all modules in the given package
Sourcefn get_normalized_move_module<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module_name: String,
) -> Pin<Box<dyn Future<Output = RpcResult<IotaMoveNormalizedModule>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_normalized_move_module<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module_name: String,
) -> Pin<Box<dyn Future<Output = RpcResult<IotaMoveNormalizedModule>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Return a structured representation of Move module
Sourcefn get_normalized_move_struct<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module_name: String,
struct_name: String,
) -> Pin<Box<dyn Future<Output = RpcResult<IotaMoveNormalizedStruct>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_normalized_move_struct<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module_name: String,
struct_name: String,
) -> Pin<Box<dyn Future<Output = RpcResult<IotaMoveNormalizedStruct>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Return a structured representation of Move struct
Sourcefn get_normalized_move_function<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module_name: String,
function_name: String,
) -> Pin<Box<dyn Future<Output = RpcResult<IotaMoveNormalizedFunction>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_normalized_move_function<'life0, 'async_trait>(
&'life0 self,
package: ObjectId,
module_name: String,
function_name: String,
) -> Pin<Box<dyn Future<Output = RpcResult<IotaMoveNormalizedFunction>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Return a structured representation of Move function
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".