pub trait CoinReadApiClient: ClientT {
// Provided methods
fn get_coins<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
coin_type: Option<String>,
cursor: Option<ObjectID>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn get_all_coins<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
cursor: Option<ObjectID>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn get_balance<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
coin_type: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Balance, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn get_all_balances<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
) -> Pin<Box<dyn Future<Output = Result<Vec<Balance>, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn get_coin_metadata<'life0, 'async_trait>(
&'life0 self,
coin_type: String,
) -> Pin<Box<dyn Future<Output = Result<Option<IotaCoinMetadata>, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn get_total_supply<'life0, 'async_trait>(
&'life0 self,
coin_type: String,
) -> Pin<Box<dyn Future<Output = Result<Supply, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn get_circulating_supply<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<IotaCirculatingSupply, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
}Expand description
Client implementation for the CoinReadApi RPC API.
Provided Methods
Sourcefn get_coins<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
coin_type: Option<String>,
cursor: Option<ObjectID>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn get_coins<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
coin_type: Option<String>,
cursor: Option<ObjectID>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Return all Coin<coin_type> objects owned by an address.
Sourcefn get_all_coins<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
cursor: Option<ObjectID>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn get_all_coins<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
cursor: Option<ObjectID>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<CoinPage, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Return all Coin objects owned by an address.
Sourcefn get_balance<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
coin_type: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Balance, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn get_balance<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
coin_type: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Balance, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Return the total coin balance for one coin type, owned by the address owner.
Sourcefn get_all_balances<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
) -> Pin<Box<dyn Future<Output = Result<Vec<Balance>, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn get_all_balances<'life0, 'async_trait>(
&'life0 self,
owner: IotaAddress,
) -> Pin<Box<dyn Future<Output = Result<Vec<Balance>, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Return the total coin balance for all coin type, owned by the address owner.
Sourcefn get_coin_metadata<'life0, 'async_trait>(
&'life0 self,
coin_type: String,
) -> Pin<Box<dyn Future<Output = Result<Option<IotaCoinMetadata>, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn get_coin_metadata<'life0, 'async_trait>(
&'life0 self,
coin_type: String,
) -> Pin<Box<dyn Future<Output = Result<Option<IotaCoinMetadata>, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Return metadata (e.g., symbol, decimals) for a coin.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.